==> apache-roller-6.0.2-rc2-source.tar.gz: roller-weblogger-6.0.2-source/app/src/main/java/org/apache/roller/weblogger/business/TestTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  The ASF licenses this file to You
 * under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.  For additional information regarding
 * copyright in this work, please see the NOTICE file in the top level
 * directory of this distribution.
 */
package org.apache.roller.weblogger.business;

import java.util.Date;
import org.apache.roller.weblogger.WebloggerException;
import org.apache.roller.weblogger.business.runnable.RollerTaskWithLeasing;

public class TestTask extends RollerTaskWithLeasing {
    public static String NAME = "TestTask";

    public TestTask() {}

    public void init() throws WebloggerException {
        this.init(TestTask.NAME);
    }

    public String getClientId() {
        return "TestTaskClientId";
    }

    public Date getStartTime(Date current) {
        return current;
    }

    public String getStartTimeDesc() {
        return "immediate";
    }

    public int getLeaseTime() {
        return 300;
    }

    public int getInterval() {
        return 1800;
    }

    public void runTask() {
    }

}

==> apache-roller-6.1.3-source.tar.gz: roller-weblogger-6.1.3-source/app/src/main/java/org/apache/roller/weblogger/business/TestTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  The ASF licenses this file to You
 * under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.  For additional information regarding
 * copyright in this work, please see the NOTICE file in the top level
 * directory of this distribution.
 */
package org.apache.roller.weblogger.business;

import java.util.Date;
import org.apache.roller.weblogger.WebloggerException;
import org.apache.roller.weblogger.business.runnable.RollerTaskWithLeasing;

public class TestTask extends RollerTaskWithLeasing {
    public static final String NAME = "TestTask";

    public TestTask() {}

    public void init() throws WebloggerException {
        this.init(TestTask.NAME);
    }

    @Override
    public String getClientId() {
        return "TestTaskClientId";
    }

    @Override
    public Date getStartTime(Date current) {
        return current;
    }

    @Override
    public String getStartTimeDesc() {
        return "immediate";
    }

    @Override
    public int getLeaseTime() {
        return 300;
    }

    @Override
    public int getInterval() {
        return 1800;
    }

    @Override
    public void runTask() {
    }

}
